sol.models.mergedplayer – Merged players — SoL 3 developers documentation

### Navigation

- index
- modules |
- next |
- previous |
- Dev's documentation »
- SoL modules »
- `sol.models` – SQLAlchemy modelization »
- Entities »

# `sol.models.mergedplayer` – Merged players

class `sol.models.mergedplayer.` `MergedPlayer`(**kwargs)

  A player who has been merged into another.

  `caption`(html=None, localized=True)

    Description of the player, made up concatenating his names.

  `description`

    Description of the player, made up concatenating his names.

  `firstname`

    Player’s first name.

  `idmergedplayer`

    Primary key.

  `idplayer`

    Target `player`‘s ID.

  `lastname`

    Player’s last name.

  `nickname`

    Player’s nickname, used also for login purposes.

  `shouldOmitNickName`()

    Determine if the nickname should be omitted because redundant.

### Navigation

- index
- modules |
- next |
- previous |
- Dev's documentation »
- SoL modules »
- `sol.models` – SQLAlchemy modelization »
- Entities »